# getotp

### Description

Tool for retrieving TOTP tokens.

### Installation

```bash
pip install getotp
```

### Usage
```bash
getotp add <name> <totp secret>
getotp show <name>  # Returns TOTP token.
```
